@@ -1,6 +1,6 @@
 # coding=utf-8
 # pynput
-# Copyright (C) 2015-2020 Moses Palmér
+# Copyright (C) 2015-2021 Moses Palmér
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -684,7 +684,7 @@ class Listener(AbstractListener):
         ``win32_event_filter``
             A callable taking the arguments ``(msg, data)``, where ``msg`` is
             the current message, and ``data`` associated data as a
-            `KBLLHOOKSTRUCT <https://msdn.microsoft.com/en-us/library/windows/desktop/ms644967(v=vs.85).aspx>`_.
+            `KBDLLHOOKSTRUCT <https://docs.microsoft.com/en-gb/windows/win32/api/winuser/ns-winuser-kbdllhookstruct>`_.
 
             If this callback returns ``False``, the event will not be
             propagated to the listener callback.
@@ -712,7 +712,7 @@ class Listener(AbstractListener):
 
         This method will convert upper case keys to lower case keys, convert
         any modifiers with a right and left version to the same value, and may
-        slao perform additional platform dependent normalisation.
+        slow perform additional platform dependent normalisation.
 
         :param key: The key to normalise.
         :type key: Key or KeyCode
