@@ -1,6 +1,6 @@
 # coding=utf-8
 # pynput
-# Copyright (C) 2015-2020 Moses Palmér
+# Copyright (C) 2015-2021 Moses Palmér
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -106,11 +106,11 @@ class KeyCode(_base.KeyCode):
         """Creates a media key from a partial name.
 
         :param str name: The name. The actual symbol name will be this string
-            with ``'XF86Audio'`` prepended.
+            with ``'XF86_Audio'`` prepended.
 
         :return: a key code
         """
-        return cls._from_symbol('XF86Audio' + name, **kwargs)
+        return cls._from_symbol('XF86_Audio' + name, **kwargs)
 
 
 # pylint: disable=W0212
